@@ -205,7 +205,7 @@ loo.design2 <- function(x, w, constraint, ptConstr, knots,
 	}
     }
     if(fieq)
-	return(list(Xeq = Xeq, Xieq = Xieq, fieq = fieq, niqc1 = niqc1))
+	list(Xeq = Xeq, Xieq = Xieq, fieq = fieq, niqc1 = niqc1)
     else
-	return(list(Xeq = Xeq,              fieq = fieq, niqc1 = niqc1))
-} ## loo.design
+	list(Xeq = Xeq,              fieq = fieq, niqc1 = niqc1)
+} ## loo.design2
